@@ -49,14 +49,18 @@
 #include "prot.h"
 #include "mboxname.h"
 #include "signals.h"
+#include "imapparse.h"
 #include "util.h"
 
 #define MAX_SESSIONID_SIZE 256
 
+/* This is a string because we only ever use it as a string */
+#define SPHINX_MAX_MATCHES          "1000000"
+
 /* Flags for cyrus_init() */
 enum {
-    CYRUSINIT_NODB =	(1<<0),
-    CYRUSINIT_PERROR =	(1<<1)
+    CYRUSINIT_NODB =    (1<<0),
+    CYRUSINIT_PERROR =  (1<<1)
 };
 
 /* Startup the configuration subsystem */
@@ -64,48 +68,48 @@ enum {
  * for any libimap/libcyrus process, and should be called fairly early
  * (and needs an associated cyrus_done call) */
 extern int cyrus_init(const char *alt_config, const char *ident,
-		      unsigned flags, int config_need_data);
+                      unsigned flags, int config_need_data);
 extern void global_sasl_init(int client, int server,
-			     const sasl_callback_t *callbacks);
+                             const sasl_callback_t *callbacks);
 
 /* Shutdown a cyrus process */
 extern void cyrus_done(void);
 
 /* sasl configuration */
 extern int mysasl_config(void *context,
-			 const char *plugin_name,
-			 const char *option,
-			 const char **result,
-			 unsigned *len);
+                         const char *plugin_name,
+                         const char *option,
+                         const char **result,
+                         unsigned *len);
 extern sasl_security_properties_t *mysasl_secprops(int flags);
 
 typedef int (mysasl_cb_ft)(void);
 
 /* user canonification */
 extern const char *canonify_userid(char *user, const char *loginid,
-				   int *domain_from_ip);
+                                   int *domain_from_ip);
 
 extern int is_userid_anonymous(const char *user);
 
 extern int mysasl_canon_user(sasl_conn_t *conn,
-		             void *context,
-		             const char *user, unsigned ulen,
-		             unsigned flags,
-		             const char *user_realm,
-		             char *out_user,
-		             unsigned out_max, unsigned *out_ulen);
+                             void *context,
+                             const char *user, unsigned ulen,
+                             unsigned flags,
+                             const char *user_realm,
+                             char *out_user,
+                             unsigned out_max, unsigned *out_ulen);
 
 extern int mysasl_proxy_policy(sasl_conn_t *conn,
-			       void *context,
-			       const char *requested_user, unsigned rlen,
-			       const char *auth_identity, unsigned alen,
-			       const char *def_realm __attribute__((unused)),
-			       unsigned urlen __attribute__((unused)),
-			       struct propctx *propctx __attribute__((unused)));
+                               void *context,
+                               const char *requested_user, unsigned rlen,
+                               const char *auth_identity, unsigned alen,
+                               const char *def_realm __attribute__((unused)),
+                               unsigned urlen __attribute__((unused)),
+                               struct propctx *propctx __attribute__((unused)));
 
 /* check if `authstate' is a valid member of class */
-extern int global_authisa(struct auth_state *authstate, 
-			  enum imapopt opt);
+extern int global_authisa(struct auth_state *authstate,
+                          enum imapopt opt);
 
 /* useful types */
 struct protstream;
@@ -118,56 +122,12 @@ struct proxy_context {
     int *userisproxyadmin;
 };
 
-/* imap parsing functions (imapparse.c) */
-int getword(struct protstream *in, struct buf *buf);
-
-/* Flags for getxstring() */
-/* IMAP_BIN_ASTRING is an IMAP_ASTRING that does not perform the
- * does-not-contain-a-NULL check (in the case of a literal) */
-enum getxstring_flags {
-    GXS_ATOM	= (1<<0),   /* result may be a bare atom */
-    GXS_QUOTED	= (1<<1),   /* result may be "quoted" */
-    GXS_LITERAL	= (1<<2),   /* result may be {N}literal */
-    GXS_NIL	= (1<<3),   /* result may be the special atom NIL */
-    GXS_BINARY	= (1<<4),   /* result may contain embedded NULs */
-
-    IMAP_ASTRING = GXS_ATOM|GXS_QUOTED|GXS_LITERAL,
-    IMAP_BIN_ASTRING = IMAP_ASTRING|GXS_BINARY,
-    IMAP_NSTRING = GXS_NIL|GXS_QUOTED|GXS_LITERAL,
-    IMAP_BIN_NSTRING = IMAP_NSTRING|GXS_BINARY,
-    IMAP_QSTRING = GXS_QUOTED,
-    IMAP_STRING = GXS_QUOTED|GXS_LITERAL,
-
-    /* note: there's some consistency issues here... the special
-     * value "NIL" must be quoted to get returned as a string */
-    IMAP_NASTRING = GXS_NIL|GXS_ATOM|GXS_QUOTED|GXS_LITERAL,
-};
-
-int getxstring(struct protstream *pin, struct protstream *pout,
-	       struct buf *buf, enum getxstring_flags);
-#define getastring(pin, pout, buf) getxstring((pin), (pout), (buf), IMAP_ASTRING)
-#define getbastring(pin, pout, buf) getxstring((pin), (pout), (buf), IMAP_BIN_ASTRING)
-#define getnstring(pin, pout, buf) getxstring((pin), (pout), (buf), IMAP_NSTRING)
-#define getbnstring(pin, pout, buf) getxstring((pin), (pout), (buf), IMAP_BIN_NSTRING)
-#define getqstring(pin, pout, buf) getxstring((pin), (pout), (buf), IMAP_QSTRING)
-#define getstring(pin, pout, buf) getxstring((pin), (pout), (buf), IMAP_STRING)
-#define getnastring(pin, pout, buf) getxstring((pin), (pout), (buf), IMAP_NASTRING)
-int getint32(struct protstream *pin, int *num);
-int getsint32(struct protstream *pin, int *num);
-int getuint32(struct protstream *pin, unsigned int *num);
-int getint64(struct protstream *pin, int64_t *num);
-int getsint64(struct protstream *pin, int64_t *num);
-int getuint64(struct protstream *pin, uint64_t *num);
-int getmodseq(struct protstream *pin, modseq_t *num);
-
-void eatline(struct protstream *pin, int c);
-
 /* Misc utils */
 extern int shutdown_file(char *buf, int size);
 extern char *find_msgid(char *, char **);
 #define UNIX_SOCKET "[unix socket]"
 extern const char *get_clienthost(int s,
-				  const char **localip, const char **remoteip);
+                                  const char **localip, const char **remoteip);
 
 /* Misc globals */
 extern int in_shutdown;
@@ -186,7 +146,14 @@ extern const char *config_ptscache_db;
 extern const char *config_statuscache_db;
 extern const char *config_userdeny_db;
 extern const char *config_zoneinfo_db;
+extern const char *config_conversations_db;
+extern const char *config_backup_db;
+extern const char *config_jmapauth_db;
+extern int config_jmapauth_allowsasl;
+extern int config_jmapauth_token_ttl;
+extern int config_jmapauth_loginid_ttl;
 extern int charset_flags;
+extern int charset_snippet_flags;
 
 /* Session ID */
 extern void session_new_id(void);
@@ -196,4 +163,6 @@ extern void parse_sessionid(const char *str, char *sessionid);
 /* Capability suppression */
 extern int capa_is_disabled(const char *str);
 
+extern int cmd_cancelled();
+
 #endif /* INCLUDED_GLOBAL_H */
