@@ -45,7 +45,6 @@
 
 #include <ctype.h>
 #include <assert.h>
-#include <jansson.h>
 #include <string.h>
 #include <syslog.h>
 #ifdef HAVE_UNISTD_H
@@ -62,7 +61,7 @@
 #include "http_dav.h"
 #include "http_jmap.h"
 #include "ical_support.h"
-#include "imap_err.h"
+#include "json_support.h"
 #include "jmap_ical.h"
 #include "search_query.h"
 #include "stristr.h"
@@ -72,7 +71,7 @@
 
 /* generated headers are not necessarily in current directory */
 #include "imap/http_err.h"
-
+#include "imap/imap_err.h"
 
 static int getCalendars(struct jmap_req *req);
 static int getCalendarUpdates(struct jmap_req *req);
@@ -118,8 +117,6 @@ struct updates_rock {
     size_t seen_records;
     size_t max_records;
 
-    struct mailbox *mailbox;
-    short fetchmodseq;
     modseq_t highestmodseq;
 };
 
@@ -160,30 +157,8 @@ static void updates_rock_update(struct updates_rock *rock,
         json_array_append_new(rock->removed, json_string(uid));
     }
 
-    /* Fetch record to determine modseq. */
-    if (rock->fetchmodseq) {
-        struct index_record record;
-        int r;
-
-        if (!rock->mailbox || strcmp(rock->mailbox->name, dav.mailbox)) {
-            mailbox_close(&rock->mailbox);
-            r = mailbox_open_irl(dav.mailbox, &rock->mailbox);
-            if (r) {
-                syslog(LOG_INFO, "mailbox_open_irl(%s) failed: %s",
-                        dav.mailbox, error_message(r));
-                return;
-            }
-        }
-        r = mailbox_find_index_record(rock->mailbox, dav.imap_uid, &record);
-        if (r) {
-            syslog(LOG_INFO, "mailbox_find_index_record(%s,%d) failed: %s",
-                    rock->mailbox->name, dav.imap_uid, error_message(r));
-            mailbox_close(&rock->mailbox);
-            return;
-        }
-        if (record.modseq > rock->highestmodseq) {
-            rock->highestmodseq = record.modseq;
-        }
+    if (dav.modseq > rock->highestmodseq) {
+        rock->highestmodseq = dav.modseq;
     }
 }
 
@@ -1312,6 +1287,7 @@ static int getcalendarevents_cb(void *rock, struct caldav_data *cdata)
          * to a Cyrus hash, but the jmapical API requires a JSON object. */
         strarray_t *keys = hash_keys(crock->props);
         int i;
+        jprops = json_pack("{}");
         for (i = 0; i < strarray_size(keys); i++) {
             json_object_set(jprops, strarray_nth(keys, i), json_null());
         }
@@ -2069,13 +2045,11 @@ static int getCalendarEventUpdates(struct jmap_req *req)
     json_decref(invalid);
 
     /* Lookup updates. */
-    rock.fetchmodseq = 1;
     rock.changed = json_array();
     rock.removed = json_array();
     rock.max_records = maxChanges;
     r = caldav_get_updates(db, oldmodseq, NULL /*mboxname*/, CAL_COMP_VEVENT, 
             maxChanges ? maxChanges + 1 : -1, &geteventupdates_cb, &rock);
-    mailbox_close(&rock.mailbox);
     if (r) goto done;
     strip_spurious_deletes(&rock);
 
